@@ -719,7 +719,7 @@ class PhIDEBase(object):
         step_create_response = step_client.create_state_machine(
             name=self.name + random_num,
             definition=create_definition,
-            roleArn=os.getenv("DEFAULT_ROLE_ARN"),
+            roleArn=dv.DEFAULT_ROLE_ARN,
             type=dv.DEFAULT_MACHINE_TYPE,
         )
         # 获取cluster_id
@@ -758,6 +758,7 @@ class PhIDEBase(object):
                 )
                 raise Exception("Job运行失败")
                 break
+            time.sleep(60)
 
 
     def status(self, **kwargs):
